@@ -105,8 +105,8 @@ connectivity_nm_state_change_cb (NMClient *client,
   new_nm_connected = !(state == NM_STATE_CONNECTING
       || state == NM_STATE_DISCONNECTED);
 
-  DEBUG ("New NetworkManager network state %d (connected: %d", state,
-    new_nm_connected);
+  DEBUG ("New NetworkManager network state %d (connected: %s)", state,
+      new_nm_connected ? "true" : "false");
 
   connectivity_change_state (connectivity, new_nm_connected);
 }
@@ -207,8 +207,8 @@ empathy_connectivity_init (EmpathyConnectivity *connectivity)
   if (connection != NULL)
     {
       priv->proxy = dbus_g_proxy_new_for_name (connection,
-          "org.moblin.connman", "/",
-          "org.moblin.connman.Manager");
+          "net.connman", "/",
+          "net.connman.Manager");
 
       dbus_g_object_register_marshaller (
           _empathy_marshal_VOID__STRING,
@@ -403,7 +403,7 @@ empathy_connectivity_set_use_conn (EmpathyConnectivity *connectivity,
   if (use_conn == priv->use_conn)
     return;
 
-  DEBUG ("use_conn gconf key changed; new value = %s",
+  DEBUG ("use_conn GSetting key changed; new value = %s",
       use_conn ? "true" : "false");
 
   priv->use_conn = use_conn;
