@@ -539,7 +539,7 @@ empathy_protocol_name_to_display_name (const gchar *proto_name)
   } names[] = {
     { "jabber", "Jabber", FALSE },
     { "gtalk", "Google Talk", FALSE },
-    { "msn", "MSN", FALSE, },
+    { "msn", "Windows Live (MSN)", FALSE, },
     { "local-xmpp", N_("People Nearby"), TRUE },
     { "irc", "IRC", FALSE },
     { "icq", "ICQ", FALSE },
